@@ -14,6 +14,7 @@ client_2          -> client_2_smpl_1, client_2_id
                      client_2_smpl_3, client_2_id
 """
 import logging
+import warnings
 
 import pytorch_lightning as pl
 import torch
@@ -28,9 +29,10 @@ from ptls.data_load.iterable_processing.feature_filter import FeatureFilter
 from ptls.data_load.iterable_processing.iterable_shuffle import IterableShuffle
 from ptls.data_load.iterable_processing.seq_len_filter import SeqLenFilter
 from ptls.data_load.list_splitter import ListSplitter
-from ptls.data_load.parquet_dataset import ParquetDataset, ParquetFiles
+from ptls.data_load.datasets.parquet_dataset import ParquetDataset, ParquetFiles
 from ptls.data_load.partitioned_dataset import PartitionedDataset, PartitionedDataFiles
-from ptls.metric_learn.dataset import split_strategy, nested_list_to_flat_with_collate
+from ptls.metric_learn.dataset import nested_list_to_flat_with_collate
+from ptls.frames.coles import split_strategy
 from ptls.metric_learn.dataset.splitting_dataset import IterableSplittingDataset, MapSplittingDataset
 
 logger = logging.getLogger(__name__)
@@ -45,6 +47,9 @@ def coles_collate_fn(batch):
 
 class ColesDataModuleTrain(pl.LightningDataModule):
     def __init__(self, type, setup, train, valid, pl_module):
+        warnings.warn('Use `ptls.frames.PtlsDataModule` '
+                      'with `ptls.frames.coles.ColesDataset` or `ptls.frames.coles.ColesIterableDataset`',
+                      DeprecationWarning)
         super().__init__()
 
         self._type = type
