@@ -1,9 +1,10 @@
-from .datasets.mlm_dataset import MlmDataset, MlmIterableDataset
-from .datasets.mlm_indexed_dataset import MlmIndexedDataset
+from .datasets.mlm_dataset import MlmDataset, MlmIterableDataset, MLMNSPDataset
+from .datasets.mlm_indexed_dataset import MlmIndexedDataset, MLMNSPIndexedDataset
 from .datasets.rtd_dataset import RtdDataset, RtdIterableDataset
 from .datasets.sop_dataset import SopDataset, SopIterableDataset
 from .datasets.nsp_dataset import NspDataset, NspIterableDataset
 
 from .modules.mlm_module import MLMPretrainModule
+from .modules.mlm_nsp_module import MLMNSPModule
 from .modules.rtd_module import RtdModule
 from .modules.sop_nsp_module import SopNspModule
